ElementDamageSet

Struct ElementDamageSet 

pub(crate) struct ElementDamageSet<'a> {
    node: ServoLayoutNode<'a>,
    pub from_parent: LayoutDamage,
    pub on_element: LayoutDamage,
    pub from_children: LayoutDamage,
    pub incoming_layout_root_count: usize,
}

Fields

node: ServoLayoutNode<'a>from_parent: LayoutDamageon_element: LayoutDamagefrom_children: LayoutDamageincoming_layout_root_count: usize

Implementations

Source

impl<'a> ElementDamageSet<'a>

fn isolate_incoming_damage(&mut self) -> LayoutDamage

Given the damage on the element and damage from parents, determine which damage should be passed to children, returning that value.

fn propagate_damage_to_children( &mut self, layout_context: &LayoutContext<'_>, has_dirty_descendants: bool, damage_for_children: LayoutDamage, layout_roots: &mut Vec<LayoutRoot<'a>>, )

Given the damage the damage to children and whether or not this element had any dirty descendants, conditionally propagated damage to children and set the resulting damage from children on this ElementDamageSet.

fn apply_damage( self, layout_context: &LayoutContext<'_>, layout_roots: &mut Vec<LayoutRoot<'a>>, ) -> LayoutDamage

Given the damage from this element, the parent, and children, determine what action to take for this element’s boxes and return the damage that should be propagated to parents.

fn box_damage_action(&self) -> BoxDamageAction<'a>

fn adjust_inline_content_size_damage( &self, damage_for_parent: &mut LayoutDamage, inline_size_depends_on_content: bool, )